.. currentmodule:: cratermaker

.. image:: ../_static/projectile_icon.svg
    :alt: Projectile
    :align: center
    :width: 300px

.. _ug-projectile:

Projectile
==========

The Projectile component contains information about the populations of projectiles that are used when scaling between crater and projectile sizes.